==> huaweicloudsdkservicestage-3.1.54-py2.py3-none-any.whl: huaweicloudsdkservicestage/v3/model/show_environments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowEnvironmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'environments': 'list[EnvironmentListView]'
    }

    attribute_map = {
        'count': 'count',
        'environments': 'environments'
    }

    def __init__(self, count=None, environments=None):
        """ShowEnvironmentsResponse

        The model defined in huaweicloud sdk

        :param count: total number of enviroment
        :type count: int
        :param environments: 
        :type environments: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        
        super(ShowEnvironmentsResponse, self).__init__()

        self._count = None
        self._environments = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if environments is not None:
            self.environments = environments

    @property
    def count(self):
        """Gets the count of this ShowEnvironmentsResponse.

        total number of enviroment

        :return: The count of this ShowEnvironmentsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ShowEnvironmentsResponse.

        total number of enviroment

        :param count: The count of this ShowEnvironmentsResponse.
        :type count: int
        """
        self._count = count

    @property
    def environments(self):
        """Gets the environments of this ShowEnvironmentsResponse.

        :return: The environments of this ShowEnvironmentsResponse.
        :rtype: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this ShowEnvironmentsResponse.

        :param environments: The environments of this ShowEnvironmentsResponse.
        :type environments: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        self._environments = environments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowEnvironmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.1.144-py2.py3-none-any.whl: huaweicloudsdkservicestage/v3/model/show_environments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowEnvironmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'environments': 'list[EnvironmentListView]'
    }

    attribute_map = {
        'count': 'count',
        'environments': 'environments'
    }

    def __init__(self, count=None, environments=None):
        r"""ShowEnvironmentsResponse

        The model defined in huaweicloud sdk

        :param count: total number of enviroment
        :type count: int
        :param environments: 
        :type environments: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        
        super(ShowEnvironmentsResponse, self).__init__()

        self._count = None
        self._environments = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if environments is not None:
            self.environments = environments

    @property
    def count(self):
        r"""Gets the count of this ShowEnvironmentsResponse.

        total number of enviroment

        :return: The count of this ShowEnvironmentsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ShowEnvironmentsResponse.

        total number of enviroment

        :param count: The count of this ShowEnvironmentsResponse.
        :type count: int
        """
        self._count = count

    @property
    def environments(self):
        r"""Gets the environments of this ShowEnvironmentsResponse.

        :return: The environments of this ShowEnvironmentsResponse.
        :rtype: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        r"""Sets the environments of this ShowEnvironmentsResponse.

        :param environments: The environments of this ShowEnvironmentsResponse.
        :type environments: list[:class:`huaweicloudsdkservicestage.v3.EnvironmentListView`]
        """
        self._environments = environments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowEnvironmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
